<?php

return [
    'Names' => [
        'af' => 'આફ્રિકન્સ',
        'af_NA' => 'આફ્રિકન્સ (નામિબિયા)',
        'af_ZA' => 'આફ્રિકન્સ (દક્ષિણ આફ્રિકા)',
        'ak' => 'અકાન',
        'ak_GH' => 'અકાન (ઘાના)',
        'am' => 'એમ્હારિક',
        'am_ET' => 'એમ્હારિક (ઇથિઓપિયા)',
        'ar' => 'અરબી',
        'ar_001' => 'અરબી (વિશ્વ)',
        'ar_AE' => 'અરબી (યુનાઇટેડ આરબ અમીરાત)',
        'ar_BH' => 'અરબી (બેહરીન)',
        'ar_DJ' => 'અરબી (જીબૌટી)',
        'ar_DZ' => 'અરબી (અલ્જીરિયા)',
        'ar_EG' => 'અરબી (ઇજિપ્ત)',
        'ar_EH' => 'અરબી (પશ્ચિમી સહારા)',
        'ar_ER' => 'અરબી (એરિટ્રિયા)',
        'ar_IL' => 'અરબી (ઇઝરાઇલ)',
        'ar_IQ' => 'અરબી (ઇરાક)',
        'ar_JO' => 'અરબી (જોર્ડન)',
        'ar_KM' => 'અરબી (કોમોરસ)',
        'ar_KW' => 'અરબી (કુવૈત)',
        'ar_LB' => 'અરબી (લેબનોન)',
        'ar_LY' => 'અરબી (લિબિયા)',
        'ar_MA' => 'અરબી (મોરોક્કો)',
        'ar_MR' => 'અરબી (મૌરિટાનિયા)',
        'ar_OM' => 'અરબી (ઓમાન)',
        'ar_PS' => 'અરબી (પેલેસ્ટિનિયન ટેરિટરી)',
        'ar_QA' => 'અરબી (કતાર)',
        'ar_SA' => 'અરબી (સાઉદી અરેબિયા)',
        'ar_SD' => 'અરબી (સુદાન)',
        'ar_SO' => 'અરબી (સોમાલિયા)',
        'ar_SS' => 'અરબી (દક્ષિણ સુદાન)',
        'ar_SY' => 'અરબી (સીરિયા)',
        'ar_TD' => 'અરબી (ચાડ)',
        'ar_TN' => 'અરબી (ટ્યુનિશિયા)',
        'ar_YE' => 'અરબી (યમન)',
        'as' => 'આસામી',
        'as_IN' => 'આસામી (ભારત)',
        'az' => 'અઝરબૈજાની',
        'az_AZ' => 'અઝરબૈજાની (અઝરબૈજાન)',
        'az_Cyrl' => 'અઝરબૈજાની (સિરિલિક)',
        'az_Cyrl_AZ' => 'અઝરબૈજાની (સિરિલિક, અઝરબૈજાન)',
        'az_Latn' => 'અઝરબૈજાની (લેટિન)',
        'az_Latn_AZ' => 'અઝરબૈજાની (લેટિન, અઝરબૈજાન)',
        'be' => 'બેલારુશિયન',
        'be_BY' => 'બેલારુશિયન (બેલારુસ)',
        'bg' => 'બલ્ગેરિયન',
        'bg_BG' => 'બલ્ગેરિયન (બલ્ગેરિયા)',
        'bm' => 'બામ્બારા',
        'bm_ML' => 'બામ્બારા (માલી)',
        'bn' => 'બાંગ્લા',
        'bn_BD' => 'બાંગ્લા (બાંગ્લાદેશ)',
        'bn_IN' => 'બાંગ્લા (ભારત)',
        'bo' => 'તિબેટીયન',
        'bo_CN' => 'તિબેટીયન (ચીન)',
        'bo_IN' => 'તિબેટીયન (ભારત)',
        'br' => 'બ્રેટોન',
        'br_FR' => 'બ્રેટોન (ફ્રાંસ)',
        'bs' => 'બોસ્નિયન',
        'bs_BA' => 'બોસ્નિયન (બોસ્નિયા અને હર્ઝેગોવિના)',
        'bs_Cyrl' => 'બોસ્નિયન (સિરિલિક)',
        'bs_Cyrl_BA' => 'બોસ્નિયન (સિરિલિક, બોસ્નિયા અને હર્ઝેગોવિના)',
        'bs_Latn' => 'બોસ્નિયન (લેટિન)',
        'bs_Latn_BA' => 'બોસ્નિયન (લેટિન, બોસ્નિયા અને હર્ઝેગોવિના)',
        'ca' => 'કતલાન',
        'ca_AD' => 'કતલાન (ઍંડોરા)',
        'ca_ES' => 'કતલાન (સ્પેન)',
        'ca_FR' => 'કતલાન (ફ્રાંસ)',
        'ca_IT' => 'કતલાન (ઇટાલી)',
        'ce' => 'ચેચન',
        'ce_RU' => 'ચેચન (રશિયા)',
        'cs' => 'ચેક',
        'cs_CZ' => 'ચેક (ચેકીયા)',
        'cv' => 'ચૂવાશ',
        'cv_RU' => 'ચૂવાશ (રશિયા)',
        'cy' => 'વેલ્શ',
        'cy_GB' => 'વેલ્શ (યુનાઇટેડ કિંગડમ)',
        'da' => 'ડેનિશ',
        'da_DK' => 'ડેનિશ (ડેનમાર્ક)',
        'da_GL' => 'ડેનિશ (ગ્રીનલેન્ડ)',
        'de' => 'જર્મન',
        'de_AT' => 'જર્મન (ઑસ્ટ્રિયા)',
        'de_BE' => 'જર્મન (બેલ્જીયમ)',
        'de_CH' => 'જર્મન (સ્વિટ્ઝર્લૅન્ડ)',
        'de_DE' => 'જર્મન (જર્મની)',
        'de_IT' => 'જર્મન (ઇટાલી)',
        'de_LI' => 'જર્મન (લૈચટેંસ્ટેઇન)',
        'de_LU' => 'જર્મન (લક્ઝમબર્ગ)',
        'dz' => 'ડ્ઝોંગ્ખા',
        'dz_BT' => 'ડ્ઝોંગ્ખા (ભૂટાન)',
        'ee' => 'ઈવ',
        'ee_GH' => 'ઈવ (ઘાના)',
        'ee_TG' => 'ઈવ (ટોગો)',
        'el' => 'ગ્રીક',
        'el_CY' => 'ગ્રીક (સાયપ્રસ)',
        'el_GR' => 'ગ્રીક (ગ્રીસ)',
        'en' => 'અંગ્રેજી',
        'en_001' => 'અંગ્રેજી (વિશ્વ)',
        'en_150' => 'અંગ્રેજી (યુરોપ)',
        'en_AE' => 'અંગ્રેજી (યુનાઇટેડ આરબ અમીરાત)',
        'en_AG' => 'અંગ્રેજી (ઍન્ટિગુઆ અને બર્મુડા)',
        'en_AI' => 'અંગ્રેજી (ઍંગ્વિલા)',
        'en_AS' => 'અંગ્રેજી (અમેરિકન સમોઆ)',
        'en_AT' => 'અંગ્રેજી (ઑસ્ટ્રિયા)',
        'en_AU' => 'અંગ્રેજી (ઑસ્ટ્રેલિયા)',
        'en_BB' => 'અંગ્રેજી (બારબાડોસ)',
        'en_BE' => 'અંગ્રેજી (બેલ્જીયમ)',
        'en_BI' => 'અંગ્રેજી (બુરુંડી)',
        'en_BM' => 'અંગ્રેજી (બર્મુડા)',
        'en_BS' => 'અંગ્રેજી (બહામાસ)',
        'en_BW' => 'અંગ્રેજી (બોત્સ્વાના)',
        'en_BZ' => 'અંગ્રેજી (બેલીઝ)',
        'en_CA' => 'અંગ્રેજી (કેનેડા)',
        'en_CC' => 'અંગ્રેજી (કોકોઝ [કીલીંગ] આઇલેન્ડ્સ)',
        'en_CH' => 'અંગ્રેજી (સ્વિટ્ઝર્લૅન્ડ)',
        'en_CK' => 'અંગ્રેજી (કુક આઇલેન્ડ્સ)',
        'en_CM' => 'અંગ્રેજી (કૅમરૂન)',
        'en_CX' => 'અંગ્રેજી (ક્રિસમસ આઇલેન્ડ)',
        'en_CY' => 'અંગ્રેજી (સાયપ્રસ)',
        'en_DE' => 'અંગ્રેજી (જર્મની)',
        'en_DK' => 'અંગ્રેજી (ડેનમાર્ક)',
        'en_DM' => 'અંગ્રેજી (ડોમિનિકા)',
        'en_ER' => 'અંગ્રેજી (એરિટ્રિયા)',
        'en_FI' => 'અંગ્રેજી (ફિનલેન્ડ)',
        'en_FJ' => 'અંગ્રેજી (ફીજી)',
        'en_FK' => 'અંગ્રેજી (ફૉકલેન્ડ આઇલેન્ડ્સ)',
        'en_FM' => 'અંગ્રેજી (માઇક્રોનેશિયા)',
        'en_GB' => 'અંગ્રેજી (યુનાઇટેડ કિંગડમ)',
        'en_GD' => 'અંગ્રેજી (ગ્રેનેડા)',
        'en_GG' => 'અંગ્રેજી (ગ્વેર્નસે)',
        'en_GH' => 'અંગ્રેજી (ઘાના)',
        'en_GI' => 'અંગ્રેજી (જીબ્રાલ્ટર)',
        'en_GM' => 'અંગ્રેજી (ગેમ્બિયા)',
        'en_GU' => 'અંગ્રેજી (ગ્વામ)',
        'en_GY' => 'અંગ્રેજી (ગયાના)',
        'en_HK' => 'અંગ્રેજી (હોંગકોંગ SAR ચીન)',
        'en_IE' => 'અંગ્રેજી (આયર્લેન્ડ)',
        'en_IL' => 'અંગ્રેજી (ઇઝરાઇલ)',
        'en_IM' => 'અંગ્રેજી (આઇલ ઑફ મેન)',
        'en_IN' => 'અંગ્રેજી (ભારત)',
        'en_IO' => 'અંગ્રેજી (બ્રિટિશ ઇન્ડિયન ઓશન ટેરિટરી)',
        'en_JE' => 'અંગ્રેજી (જર્સી)',
        'en_JM' => 'અંગ્રેજી (જમૈકા)',
        'en_KE' => 'અંગ્રેજી (કેન્યા)',
        'en_KI' => 'અંગ્રેજી (કિરિબાટી)',
        'en_KN' => 'અંગ્રેજી (સેંટ કિટ્સ અને નેવિસ)',
        'en_KY' => 'અંગ્રેજી (કેમેન આઇલેન્ડ્સ)',
        'en_LC' => 'અંગ્રેજી (સેંટ લુસિયા)',
        'en_LR' => 'અંગ્રેજી (લાઇબેરિયા)',
        'en_LS' => 'અંગ્રેજી (લેસોથો)',
        'en_MG' => 'અંગ્રેજી (મેડાગાસ્કર)',
        'en_MH' => 'અંગ્રેજી (માર્શલ આઇલેન્ડ્સ)',
        'en_MO' => 'અંગ્રેજી (મકાઉ SAR ચીન)',
        'en_MP' => 'અંગ્રેજી (ઉત્તરી મારિયાના આઇલેન્ડ્સ)',
        'en_MS' => 'અંગ્રેજી (મોંટસેરાત)',
        'en_MT' => 'અંગ્રેજી (માલ્ટા)',
        'en_MU' => 'અંગ્રેજી (મોરિશિયસ)',
        'en_MV' => 'અંગ્રેજી (માલદિવ્સ)',
        'en_MW' => 'અંગ્રેજી (માલાવી)',
        'en_MY' => 'અંગ્રેજી (મલેશિયા)',
        'en_NA' => 'અંગ્રેજી (નામિબિયા)',
        'en_NF' => 'અંગ્રેજી (નોરફોક આઇલેન્ડ્સ)',
        'en_NG' => 'અંગ્રેજી (નાઇજેરિયા)',
        'en_NL' => 'અંગ્રેજી (નેધરલેન્ડ્સ)',
        'en_NR' => 'અંગ્રેજી (નૌરુ)',
        'en_NU' => 'અંગ્રેજી (નીયુ)',
        'en_NZ' => 'અંગ્રેજી (ન્યુઝીલેન્ડ)',
        'en_PG' => 'અંગ્રેજી (પાપુઆ ન્યૂ ગિની)',
        'en_PH' => 'અંગ્રેજી (ફિલિપિન્સ)',
        'en_PK' => 'અંગ્રેજી (પાકિસ્તાન)',
        'en_PN' => 'અંગ્રેજી (પીટકૈર્ન આઇલેન્ડ્સ)',
        'en_PR' => 'અંગ્રેજી (પ્યુઅર્ટો રિકો)',
        'en_PW' => 'અંગ્રેજી (પલાઉ)',
        'en_RW' => 'અંગ્રેજી (રવાંડા)',
        'en_SB' => 'અંગ્રેજી (સોલોમન આઇલેન્ડ્સ)',
        'en_SC' => 'અંગ્રેજી (સેશેલ્સ)',
        'en_SD' => 'અંગ્રેજી (સુદાન)',
        'en_SE' => 'અંગ્રેજી (સ્વીડન)',
        'en_SG' => 'અંગ્રેજી (સિંગાપુર)',
        'en_SH' => 'અંગ્રેજી (સેંટ હેલેના)',
        'en_SI' => 'અંગ્રેજી (સ્લોવેનિયા)',
        'en_SL' => 'અંગ્રેજી (સીએરા લેઓન)',
        'en_SS' => 'અંગ્રેજી (દક્ષિણ સુદાન)',
        'en_SX' => 'અંગ્રેજી (સિંટ માર્ટેન)',
        'en_SZ' => 'અંગ્રેજી (એસ્વાટીની)',
        'en_TC' => 'અંગ્રેજી (તુર્ક્સ અને કેકોઝ આઇલેન્ડ્સ)',
        'en_TK' => 'અંગ્રેજી (ટોકેલાઉ)',
        'en_TO' => 'અંગ્રેજી (ટોંગા)',
        'en_TT' => 'અંગ્રેજી (ટ્રિનીદાદ અને ટોબેગો)',
        'en_TV' => 'અંગ્રેજી (તુવાલુ)',
        'en_TZ' => 'અંગ્રેજી (તાંઝાનિયા)',
        'en_UG' => 'અંગ્રેજી (યુગાંડા)',
        'en_UM' => 'અંગ્રેજી (યુ.એસ. આઉટલાઇનિંગ આઇલેન્ડ્સ)',
        'en_US' => 'અંગ્રેજી (યુનાઇટેડ સ્ટેટ્સ)',
        'en_VC' => 'અંગ્રેજી (સેંટ વિન્સેંટ અને ગ્રેનેડાઇંસ)',
        'en_VG' => 'અંગ્રેજી (બ્રિટિશ વર્જિન આઇલેન્ડ્સ)',
        'en_VI' => 'અંગ્રેજી (યુએસ વર્જિન આઇલેન્ડ્સ)',
        'en_VU' => 'અંગ્રેજી (વાનુઆતુ)',
        'en_WS' => 'અંગ્રેજી (સમોઆ)',
        'en_ZA' => 'અંગ્રેજી (દક્ષિણ આફ્રિકા)',
        'en_ZM' => 'અંગ્રેજી (ઝામ્બિયા)',
        'en_ZW' => 'અંગ્રેજી (ઝિમ્બાબ્વે)',
        'eo' => 'એસ્પેરાન્ટો',
        'eo_001' => 'એસ્પેરાન્ટો (વિશ્વ)',
        'es' => 'સ્પેનિશ',
        'es_419' => 'સ્પેનિશ (લેટિન અમેરિકા)',
        'es_AR' => 'સ્પેનિશ (આર્જેન્ટીના)',
        'es_BO' => 'સ્પેનિશ (બોલિવિયા)',
        'es_BR' => 'સ્પેનિશ (બ્રાઝિલ)',
        'es_BZ' => 'સ્પેનિશ (બેલીઝ)',
        'es_CL' => 'સ્પેનિશ (ચિલી)',
        'es_CO' => 'સ્પેનિશ (કોલમ્બિયા)',
        'es_CR' => 'સ્પેનિશ (કોસ્ટા રિકા)',
        'es_CU' => 'સ્પેનિશ (ક્યુબા)',
        'es_DO' => 'સ્પેનિશ (ડોમિનિકન રિપબ્લિક)',
        'es_EC' => 'સ્પેનિશ (એક્વાડોર)',
        'es_ES' => 'સ્પેનિશ (સ્પેન)',
        'es_GQ' => 'સ્પેનિશ (ઇક્વેટોરિયલ ગિની)',
        'es_GT' => 'સ્પેનિશ (ગ્વાટેમાલા)',
        'es_HN' => 'સ્પેનિશ (હોન્ડુરસ)',
        'es_MX' => 'સ્પેનિશ (મેક્સિકો)',
        'es_NI' => 'સ્પેનિશ (નિકારાગુઆ)',
        'es_PA' => 'સ્પેનિશ (પનામા)',
        'es_PE' => 'સ્પેનિશ (પેરુ)',
        'es_PH' => 'સ્પેનિશ (ફિલિપિન્સ)',
        'es_PR' => 'સ્પેનિશ (પ્યુઅર્ટો રિકો)',
        'es_PY' => 'સ્પેનિશ (પેરાગ્વે)',
        'es_SV' => 'સ્પેનિશ (એલ સેલ્વાડોર)',
        'es_US' => 'સ્પેનિશ (યુનાઇટેડ સ્ટેટ્સ)',
        'es_UY' => 'સ્પેનિશ (ઉરુગ્વે)',
        'es_VE' => 'સ્પેનિશ (વેનેઝુએલા)',
        'et' => 'એસ્ટોનિયન',
        'et_EE' => 'એસ્ટોનિયન (એસ્ટોનિયા)',
        'eu' => 'બાસ્ક',
        'eu_ES' => 'બાસ્ક (સ્પેન)',
        'fa' => 'ફારસી',
        'fa_AF' => 'ફારસી (અફઘાનિસ્તાન)',
        'fa_IR' => 'ફારસી (ઈરાન)',
        'ff' => 'ફુલાહ',
        'ff_Adlm' => 'ફુલાહ (એડલમ)',
        'ff_Adlm_BF' => 'ફુલાહ (એડલમ, બુર્કિના ફાસો)',
        'ff_Adlm_CM' => 'ફુલાહ (એડલમ, કૅમરૂન)',
        'ff_Adlm_GH' => 'ફુલાહ (એડલમ, ઘાના)',
        'ff_Adlm_GM' => 'ફુલાહ (એડલમ, ગેમ્બિયા)',
        'ff_Adlm_GN' => 'ફુલાહ (એડલમ, ગિની)',
        'ff_Adlm_GW' => 'ફુલાહ (એડલમ, ગિની-બિસાઉ)',
        'ff_Adlm_LR' => 'ફુલાહ (એડલમ, લાઇબેરિયા)',
        'ff_Adlm_MR' => 'ફુલાહ (એડલમ, મૌરિટાનિયા)',
        'ff_Adlm_NE' => 'ફુલાહ (એડલમ, નાઇજર)',
        'ff_Adlm_NG' => 'ફુલાહ (એડલમ, નાઇજેરિયા)',
        'ff_Adlm_SL' => 'ફુલાહ (એડલમ, સીએરા લેઓન)',
        'ff_Adlm_SN' => 'ફુલાહ (એડલમ, સેનેગલ)',
        'ff_CM' => 'ફુલાહ (કૅમરૂન)',
        'ff_GN' => 'ફુલાહ (ગિની)',
        'ff_Latn' => 'ફુલાહ (લેટિન)',
        'ff_Latn_BF' => 'ફુલાહ (લેટિન, બુર્કિના ફાસો)',
        'ff_Latn_CM' => 'ફુલાહ (લેટિન, કૅમરૂન)',
        'ff_Latn_GH' => 'ફુલાહ (લેટિન, ઘાના)',
        'ff_Latn_GM' => 'ફુલાહ (લેટિન, ગેમ્બિયા)',
        'ff_Latn_GN' => 'ફુલાહ (લેટિન, ગિની)',
        'ff_Latn_GW' => 'ફુલાહ (લેટિન, ગિની-બિસાઉ)',
        'ff_Latn_LR' => 'ફુલાહ (લેટિન, લાઇબેરિયા)',
        'ff_Latn_MR' => 'ફુલાહ (લેટિન, મૌરિટાનિયા)',
        'ff_Latn_NE' => 'ફુલાહ (લેટિન, નાઇજર)',
        'ff_Latn_NG' => 'ફુલાહ (લેટિન, નાઇજેરિયા)',
        'ff_Latn_SL' => 'ફુલાહ (લેટિન, સીએરા લેઓન)',
        'ff_Latn_SN' => 'ફુલાહ (લેટિન, સેનેગલ)',
        'ff_MR' => 'ફુલાહ (મૌરિટાનિયા)',
        'ff_SN' => 'ફુલાહ (સેનેગલ)',
        'fi' => 'ફિનિશ',
        'fi_FI' => 'ફિનિશ (ફિનલેન્ડ)',
        'fo' => 'ફોરિસ્ત',
        'fo_DK' => 'ફોરિસ્ત (ડેનમાર્ક)',
        'fo_FO' => 'ફોરિસ્ત (ફેરો આઇલેન્ડ્સ)',
        'fr' => 'ફ્રેન્ચ',
        'fr_BE' => 'ફ્રેન્ચ (બેલ્જીયમ)',
        'fr_BF' => 'ફ્રેન્ચ (બુર્કિના ફાસો)',
        'fr_BI' => 'ફ્રેન્ચ (બુરુંડી)',
        'fr_BJ' => 'ફ્રેન્ચ (બેનિન)',
        'fr_BL' => 'ફ્રેન્ચ (સેંટ બાર્થેલેમી)',
        'fr_CA' => 'ફ્રેન્ચ (કેનેડા)',
        'fr_CD' => 'ફ્રેન્ચ (કોંગો - કિંશાસા)',
        'fr_CF' => 'ફ્રેન્ચ (સેન્ટ્રલ આફ્રિકન રિપબ્લિક)',
        'fr_CG' => 'ફ્રેન્ચ (કોંગો - બ્રાઝાવિલે)',
        'fr_CH' => 'ફ્રેન્ચ (સ્વિટ્ઝર્લૅન્ડ)',
        'fr_CI' => 'ફ્રેન્ચ (કોટ ડીઆઇવરી)',
        'fr_CM' => 'ફ્રેન્ચ (કૅમરૂન)',
        'fr_DJ' => 'ફ્રેન્ચ (જીબૌટી)',
        'fr_DZ' => 'ફ્રેન્ચ (અલ્જીરિયા)',
        'fr_FR' => 'ફ્રેન્ચ (ફ્રાંસ)',
        'fr_GA' => 'ફ્રેન્ચ (ગેબન)',
        'fr_GF' => 'ફ્રેન્ચ (ફ્રેંચ ગયાના)',
        'fr_GN' => 'ફ્રેન્ચ (ગિની)',
        'fr_GP' => 'ફ્રેન્ચ (ગ્વાડેલોપ)',
        'fr_GQ' => 'ફ્રેન્ચ (ઇક્વેટોરિયલ ગિની)',
        'fr_HT' => 'ફ્રેન્ચ (હૈતિ)',
        'fr_KM' => 'ફ્રેન્ચ (કોમોરસ)',
        'fr_LU' => 'ફ્રેન્ચ (લક્ઝમબર્ગ)',
        'fr_MA' => 'ફ્રેન્ચ (મોરોક્કો)',
        'fr_MC' => 'ફ્રેન્ચ (મોનાકો)',
        'fr_MF' => 'ફ્રેન્ચ (સેંટ માર્ટિન)',
        'fr_MG' => 'ફ્રેન્ચ (મેડાગાસ્કર)',
        'fr_ML' => 'ફ્રેન્ચ (માલી)',
        'fr_MQ' => 'ફ્રેન્ચ (માર્ટીનીક)',
        'fr_MR' => 'ફ્રેન્ચ (મૌરિટાનિયા)',
        'fr_MU' => 'ફ્રેન્ચ (મોરિશિયસ)',
        'fr_NC' => 'ફ્રેન્ચ (ન્યુ સેલેડોનિયા)',
        'fr_NE' => 'ફ્રેન્ચ (નાઇજર)',
        'fr_PF' => 'ફ્રેન્ચ (ફ્રેંચ પોલિનેશિયા)',
        'fr_PM' => 'ફ્રેન્ચ (સેંટ પીએરી અને મિક્યુલોન)',
        'fr_RE' => 'ફ્રેન્ચ (રીયુનિયન)',
        'fr_RW' => 'ફ્રેન્ચ (રવાંડા)',
        'fr_SC' => 'ફ્રેન્ચ (સેશેલ્સ)',
        'fr_SN' => 'ફ્રેન્ચ (સેનેગલ)',
        'fr_SY' => 'ફ્રેન્ચ (સીરિયા)',
        'fr_TD' => 'ફ્રેન્ચ (ચાડ)',
        'fr_TG' => 'ફ્રેન્ચ (ટોગો)',
        'fr_TN' => 'ફ્રેન્ચ (ટ્યુનિશિયા)',
        'fr_VU' => 'ફ્રેન્ચ (વાનુઆતુ)',
        'fr_WF' => 'ફ્રેન્ચ (વૉલિસ અને ફ્યુચુના)',
        'fr_YT' => 'ફ્રેન્ચ (મેયોટ)',
        'fy' => 'પશ્ચિમિ ફ્રિશિયન',
        'fy_NL' => 'પશ્ચિમિ ફ્રિશિયન (નેધરલેન્ડ્સ)',
        'ga' => 'આઇરિશ',
        'ga_GB' => 'આઇરિશ (યુનાઇટેડ કિંગડમ)',
        'ga_IE' => 'આઇરિશ (આયર્લેન્ડ)',
        'gd' => 'સ્કોટીસ ગેલિક',
        'gd_GB' => 'સ્કોટીસ ગેલિક (યુનાઇટેડ કિંગડમ)',
        'gl' => 'ગેલિશિયન',
        'gl_ES' => 'ગેલિશિયન (સ્પેન)',
        'gu' => 'ગુજરાતી',
        'gu_IN' => 'ગુજરાતી (ભારત)',
        'gv' => 'માંક્સ',
        'gv_IM' => 'માંક્સ (આઇલ ઑફ મેન)',
        'ha' => 'હૌસા',
        'ha_GH' => 'હૌસા (ઘાના)',
        'ha_NE' => 'હૌસા (નાઇજર)',
        'ha_NG' => 'હૌસા (નાઇજેરિયા)',
        'he' => 'હીબ્રુ',
        'he_IL' => 'હીબ્રુ (ઇઝરાઇલ)',
        'hi' => 'હિન્દી',
        'hi_IN' => 'હિન્દી (ભારત)',
        'hi_Latn' => 'હિન્દી (લેટિન)',
        'hi_Latn_IN' => 'હિન્દી (લેટિન, ભારત)',
        'hr' => 'ક્રોએશિયન',
        'hr_BA' => 'ક્રોએશિયન (બોસ્નિયા અને હર્ઝેગોવિના)',
        'hr_HR' => 'ક્રોએશિયન (ક્રોએશિયા)',
        'hu' => 'હંગેરિયન',
        'hu_HU' => 'હંગેરિયન (હંગેરી)',
        'hy' => 'આર્મેનિયન',
        'hy_AM' => 'આર્મેનિયન (આર્મેનિયા)',
        'ia' => 'ઇંટરલિંગુઆ',
        'ia_001' => 'ઇંટરલિંગુઆ (વિશ્વ)',
        'id' => 'ઇન્ડોનેશિયન',
        'id_ID' => 'ઇન્ડોનેશિયન (ઇન્ડોનેશિયા)',
        'ig' => 'ઇગ્બો',
        'ig_NG' => 'ઇગ્બો (નાઇજેરિયા)',
        'ii' => 'સિચુઆન યી',
        'ii_CN' => 'સિચુઆન યી (ચીન)',
        'is' => 'આઇસલેન્ડિક',
        'is_IS' => 'આઇસલેન્ડિક (આઇસલેન્ડ)',
        'it' => 'ઇટાલિયન',
        'it_CH' => 'ઇટાલિયન (સ્વિટ્ઝર્લૅન્ડ)',
        'it_IT' => 'ઇટાલિયન (ઇટાલી)',
        'it_SM' => 'ઇટાલિયન (સૅન મેરિનો)',
        'it_VA' => 'ઇટાલિયન (વેટિકન સિટી)',
        'ja' => 'જાપાનીઝ',
        'ja_JP' => 'જાપાનીઝ (જાપાન)',
        'jv' => 'જાવાનીસ',
        'jv_ID' => 'જાવાનીસ (ઇન્ડોનેશિયા)',
        'ka' => 'જ્યોર્જિયન',
        'ka_GE' => 'જ્યોર્જિયન (જ્યોર્જિયા)',
        'ki' => 'કિકુયૂ',
        'ki_KE' => 'કિકુયૂ (કેન્યા)',
        'kk' => 'કઝાખ',
        'kk_KZ' => 'કઝાખ (કઝાકિસ્તાન)',
        'kl' => 'કલાલ્લિસુત',
        'kl_GL' => 'કલાલ્લિસુત (ગ્રીનલેન્ડ)',
        'km' => 'ખ્મેર',
        'km_KH' => 'ખ્મેર (કંબોડિયા)',
        'kn' => 'કન્નડ',
        'kn_IN' => 'કન્નડ (ભારત)',
        'ko' => 'કોરિયન',
        'ko_KP' => 'કોરિયન (ઉત્તર કોરિયા)',
        'ko_KR' => 'કોરિયન (દક્ષિણ કોરિયા)',
        'ks' => 'કાશ્મીરી',
        'ks_Arab' => 'કાશ્મીરી (અરબી)',
        'ks_Arab_IN' => 'કાશ્મીરી (અરબી, ભારત)',
        'ks_Deva' => 'કાશ્મીરી (દેવનાગરી)',
        'ks_Deva_IN' => 'કાશ્મીરી (દેવનાગરી, ભારત)',
        'ks_IN' => 'કાશ્મીરી (ભારત)',
        'ku' => 'કુર્દિશ',
        'ku_TR' => 'કુર્દિશ (તુર્કિયે)',
        'kw' => 'કોર્નિશ',
        'kw_GB' => 'કોર્નિશ (યુનાઇટેડ કિંગડમ)',
        'ky' => 'કિર્ગીઝ',
        'ky_KG' => 'કિર્ગીઝ (કિર્ગિઝ્સ્તાન)',
        'lb' => 'લક્ઝેમબર્ગિશ',
        'lb_LU' => 'લક્ઝેમબર્ગિશ (લક્ઝમબર્ગ)',
        'lg' => 'ગાંડા',
        'lg_UG' => 'ગાંડા (યુગાંડા)',
        'ln' => 'લિંગાલા',
        'ln_AO' => 'લિંગાલા (અંગોલા)',
        'ln_CD' => 'લિંગાલા (કોંગો - કિંશાસા)',
        'ln_CF' => 'લિંગાલા (સેન્ટ્રલ આફ્રિકન રિપબ્લિક)',
        'ln_CG' => 'લિંગાલા (કોંગો - બ્રાઝાવિલે)',
        'lo' => 'લાઓ',
        'lo_LA' => 'લાઓ (લાઓસ)',
        'lt' => 'લિથુઆનિયન',
        'lt_LT' => 'લિથુઆનિયન (લિથુઆનિયા)',
        'lu' => 'લૂબા-કટાંગા',
        'lu_CD' => 'લૂબા-કટાંગા (કોંગો - કિંશાસા)',
        'lv' => 'લાતવિયન',
        'lv_LV' => 'લાતવિયન (લાત્વિયા)',
        'mg' => 'મલાગસી',
        'mg_MG' => 'મલાગસી (મેડાગાસ્કર)',
        'mi' => 'માઓરી',
        'mi_NZ' => 'માઓરી (ન્યુઝીલેન્ડ)',
        'mk' => 'મેસેડોનિયન',
        'mk_MK' => 'મેસેડોનિયન (ઉત્તર મેસેડોનિયા)',
        'ml' => 'મલયાલમ',
        'ml_IN' => 'મલયાલમ (ભારત)',
        'mn' => 'મોંગોલિયન',
        'mn_MN' => 'મોંગોલિયન (મંગોલિયા)',
        'mr' => 'મરાઠી',
        'mr_IN' => 'મરાઠી (ભારત)',
        'ms' => 'મલય',
        'ms_BN' => 'મલય (બ્રુનેઇ)',
        'ms_ID' => 'મલય (ઇન્ડોનેશિયા)',
        'ms_MY' => 'મલય (મલેશિયા)',
        'ms_SG' => 'મલય (સિંગાપુર)',
        'mt' => 'માલ્ટિઝ',
        'mt_MT' => 'માલ્ટિઝ (માલ્ટા)',
        'my' => 'બર્મીઝ',
        'my_MM' => 'બર્મીઝ (મ્યાંમાર [બર્મા])',
        'nb' => 'નોર્વેજિયન બોકમાલ',
        'nb_NO' => 'નોર્વેજિયન બોકમાલ (નૉર્વે)',
        'nb_SJ' => 'નોર્વેજિયન બોકમાલ (સ્વાલબર્ડ અને જેન મેયન)',
        'nd' => 'ઉત્તર દેબેલ',
        'nd_ZW' => 'ઉત્તર દેબેલ (ઝિમ્બાબ્વે)',
        'ne' => 'નેપાળી',
        'ne_IN' => 'નેપાળી (ભારત)',
        'ne_NP' => 'નેપાળી (નેપાળ)',
        'nl' => 'ડચ',
        'nl_AW' => 'ડચ (અરુબા)',
        'nl_BE' => 'ડચ (બેલ્જીયમ)',
        'nl_BQ' => 'ડચ (કેરેબિયન નેધરલેન્ડ્ઝ)',
        'nl_CW' => 'ડચ (ક્યુરાસાઓ)',
        'nl_NL' => 'ડચ (નેધરલેન્ડ્સ)',
        'nl_SR' => 'ડચ (સુરીનામ)',
        'nl_SX' => 'ડચ (સિંટ માર્ટેન)',
        'nn' => 'નોર્વેજિયન નાયનૉર્સ્ક',
        'nn_NO' => 'નોર્વેજિયન નાયનૉર્સ્ક (નૉર્વે)',
        'no' => 'નૉર્વેજીયન',
        'no_NO' => 'નૉર્વેજીયન (નૉર્વે)',
        'om' => 'ઓરોમો',
        'om_ET' => 'ઓરોમો (ઇથિઓપિયા)',
        'om_KE' => 'ઓરોમો (કેન્યા)',
        'or' => 'ઉડિયા',
        'or_IN' => 'ઉડિયા (ભારત)',
        'os' => 'ઓસ્સેટિક',
        'os_GE' => 'ઓસ્સેટિક (જ્યોર્જિયા)',
        'os_RU' => 'ઓસ્સેટિક (રશિયા)',
        'pa' => 'પંજાબી',
        'pa_Arab' => 'પંજાબી (અરબી)',
        'pa_Arab_PK' => 'પંજાબી (અરબી, પાકિસ્તાન)',
        'pa_Guru' => 'પંજાબી (ગુરૂમુખી)',
        'pa_Guru_IN' => 'પંજાબી (ગુરૂમુખી, ભારત)',
        'pa_IN' => 'પંજાબી (ભારત)',
        'pa_PK' => 'પંજાબી (પાકિસ્તાન)',
        'pl' => 'પોલીશ',
        'pl_PL' => 'પોલીશ (પોલેંડ)',
        'ps' => 'પશ્તો',
        'ps_AF' => 'પશ્તો (અફઘાનિસ્તાન)',
        'ps_PK' => 'પશ્તો (પાકિસ્તાન)',
        'pt' => 'પોર્ટુગીઝ',
        'pt_AO' => 'પોર્ટુગીઝ (અંગોલા)',
        'pt_BR' => 'પોર્ટુગીઝ (બ્રાઝિલ)',
        'pt_CH' => 'પોર્ટુગીઝ (સ્વિટ્ઝર્લૅન્ડ)',
        'pt_CV' => 'પોર્ટુગીઝ (કૅપ વર્ડે)',
        'pt_GQ' => 'પોર્ટુગીઝ (ઇક્વેટોરિયલ ગિની)',
        'pt_GW' => 'પોર્ટુગીઝ (ગિની-બિસાઉ)',
        'pt_LU' => 'પોર્ટુગીઝ (લક્ઝમબર્ગ)',
        'pt_MO' => 'પોર્ટુગીઝ (મકાઉ SAR ચીન)',
        'pt_MZ' => 'પોર્ટુગીઝ (મોઝામ્બિક)',
        'pt_PT' => 'પોર્ટુગીઝ (પોર્ટુગલ)',
        'pt_ST' => 'પોર્ટુગીઝ (સાઓ ટૉમ અને પ્રિંસિપે)',
        'pt_TL' => 'પોર્ટુગીઝ (તિમોર-લેસ્તે)',
        'qu' => 'ક્વેચુઆ',
        'qu_BO' => 'ક્વેચુઆ (બોલિવિયા)',
        'qu_EC' => 'ક્વેચુઆ (એક્વાડોર)',
        'qu_PE' => 'ક્વેચુઆ (પેરુ)',
        'rm' => 'રોમાન્શ',
        'rm_CH' => 'રોમાન્શ (સ્વિટ્ઝર્લૅન્ડ)',
        'rn' => 'રૂન્દી',
        'rn_BI' => 'રૂન્દી (બુરુંડી)',
        'ro' => 'રોમાનિયન',
        'ro_MD' => 'રોમાનિયન (મોલડોવા)',
        'ro_RO' => 'રોમાનિયન (રોમાનિયા)',
        'ru' => 'રશિયન',
        'ru_BY' => 'રશિયન (બેલારુસ)',
        'ru_KG' => 'રશિયન (કિર્ગિઝ્સ્તાન)',
        'ru_KZ' => 'રશિયન (કઝાકિસ્તાન)',
        'ru_MD' => 'રશિયન (મોલડોવા)',
        'ru_RU' => 'રશિયન (રશિયા)',
        'ru_UA' => 'રશિયન (યુક્રેન)',
        'rw' => 'કિન્યારવાન્ડા',
        'rw_RW' => 'કિન્યારવાન્ડા (રવાંડા)',
        'sa' => 'સંસ્કૃત',
        'sa_IN' => 'સંસ્કૃત (ભારત)',
        'sc' => 'સાર્દિનિયન',
        'sc_IT' => 'સાર્દિનિયન (ઇટાલી)',
        'sd' => 'સિંધી',
        'sd_Arab' => 'સિંધી (અરબી)',
        'sd_Arab_PK' => 'સિંધી (અરબી, પાકિસ્તાન)',
        'sd_Deva' => 'સિંધી (દેવનાગરી)',
        'sd_Deva_IN' => 'સિંધી (દેવનાગરી, ભારત)',
        'sd_IN' => 'સિંધી (ભારત)',
        'sd_PK' => 'સિંધી (પાકિસ્તાન)',
        'se' => 'ઉત્તરી સામી',
        'se_FI' => 'ઉત્તરી સામી (ફિનલેન્ડ)',
        'se_NO' => 'ઉત્તરી સામી (નૉર્વે)',
        'se_SE' => 'ઉત્તરી સામી (સ્વીડન)',
        'sg' => 'સાંગો',
        'sg_CF' => 'સાંગો (સેન્ટ્રલ આફ્રિકન રિપબ્લિક)',
        'sh' => 'સર્બો-ક્રોએશિયન',
        'sh_BA' => 'સર્બો-ક્રોએશિયન (બોસ્નિયા અને હર્ઝેગોવિના)',
        'si' => 'સિંહાલી',
        'si_LK' => 'સિંહાલી (શ્રીલંકા)',
        'sk' => 'સ્લોવૅક',
        'sk_SK' => 'સ્લોવૅક (સ્લોવેકિયા)',
        'sl' => 'સ્લોવેનિયન',
        'sl_SI' => 'સ્લોવેનિયન (સ્લોવેનિયા)',
        'sn' => 'શોના',
        'sn_ZW' => 'શોના (ઝિમ્બાબ્વે)',
        'so' => 'સોમાલી',
        'so_DJ' => 'સોમાલી (જીબૌટી)',
        'so_ET' => 'સોમાલી (ઇથિઓપિયા)',
        'so_KE' => 'સોમાલી (કેન્યા)',
        'so_SO' => 'સોમાલી (સોમાલિયા)',
        'sq' => 'અલ્બેનિયન',
        'sq_AL' => 'અલ્બેનિયન (અલ્બેનિયા)',
        'sq_MK' => 'અલ્બેનિયન (ઉત્તર મેસેડોનિયા)',
        'sr' => 'સર્બિયન',
        'sr_BA' => 'સર્બિયન (બોસ્નિયા અને હર્ઝેગોવિના)',
        'sr_Cyrl' => 'સર્બિયન (સિરિલિક)',
        'sr_Cyrl_BA' => 'સર્બિયન (સિરિલિક, બોસ્નિયા અને હર્ઝેગોવિના)',
        'sr_Cyrl_ME' => 'સર્બિયન (સિરિલિક, મૉન્ટેનેગ્રો)',
        'sr_Cyrl_RS' => 'સર્બિયન (સિરિલિક, સર્બિયા)',
        'sr_Latn' => 'સર્બિયન (લેટિન)',
        'sr_Latn_BA' => 'સર્બિયન (લેટિન, બોસ્નિયા અને હર્ઝેગોવિના)',
        'sr_Latn_ME' => 'સર્બિયન (લેટિન, મૉન્ટેનેગ્રો)',
        'sr_Latn_RS' => 'સર્બિયન (લેટિન, સર્બિયા)',
        'sr_ME' => 'સર્બિયન (મૉન્ટેનેગ્રો)',
        'sr_RS' => 'સર્બિયન (સર્બિયા)',
        'su' => 'સંડેનીઝ',
        'su_ID' => 'સંડેનીઝ (ઇન્ડોનેશિયા)',
        'su_Latn' => 'સંડેનીઝ (લેટિન)',
        'su_Latn_ID' => 'સંડેનીઝ (લેટિન, ઇન્ડોનેશિયા)',
        'sv' => 'સ્વીડિશ',
        'sv_AX' => 'સ્વીડિશ (ઑલેન્ડ આઇલેન્ડ્સ)',
        'sv_FI' => 'સ્વીડિશ (ફિનલેન્ડ)',
        'sv_SE' => 'સ્વીડિશ (સ્વીડન)',
        'sw' => 'સ્વાહિલી',
        'sw_CD' => 'સ્વાહિલી (કોંગો - કિંશાસા)',
        'sw_KE' => 'સ્વાહિલી (કેન્યા)',
        'sw_TZ' => 'સ્વાહિલી (તાંઝાનિયા)',
        'sw_UG' => 'સ્વાહિલી (યુગાંડા)',
        'ta' => 'તમિલ',
        'ta_IN' => 'તમિલ (ભારત)',
        'ta_LK' => 'તમિલ (શ્રીલંકા)',
        'ta_MY' => 'તમિલ (મલેશિયા)',
        'ta_SG' => 'તમિલ (સિંગાપુર)',
        'te' => 'તેલુગુ',
        'te_IN' => 'તેલુગુ (ભારત)',
        'tg' => 'તાજીક',
        'tg_TJ' => 'તાજીક (તાજીકિસ્તાન)',
        'th' => 'થાઈ',
        'th_TH' => 'થાઈ (થાઇલેંડ)',
        'ti' => 'ટાઇગ્રિનિયા',
        'ti_ER' => 'ટાઇગ્રિનિયા (એરિટ્રિયા)',
        'ti_ET' => 'ટાઇગ્રિનિયા (ઇથિઓપિયા)',
        'tk' => 'તુર્કમેન',
        'tk_TM' => 'તુર્કમેન (તુર્કમેનિસ્તાન)',
        'tl' => 'ટાગાલોગ',
        'tl_PH' => 'ટાગાલોગ (ફિલિપિન્સ)',
        'to' => 'ટોંગાન',
        'to_TO' => 'ટોંગાન (ટોંગા)',
        'tr' => 'ટર્કિશ',
        'tr_CY' => 'ટર્કિશ (સાયપ્રસ)',
        'tr_TR' => 'ટર્કિશ (તુર્કિયે)',
        'tt' => 'તતાર',
        'tt_RU' => 'તતાર (રશિયા)',
        'ug' => 'ઉઇગુર',
        'ug_CN' => 'ઉઇગુર (ચીન)',
        'uk' => 'યુક્રેનિયન',
        'uk_UA' => 'યુક્રેનિયન (યુક્રેન)',
        'ur' => 'ઉર્દૂ',
        'ur_IN' => 'ઉર્દૂ (ભારત)',
        'ur_PK' => 'ઉર્દૂ (પાકિસ્તાન)',
        'uz' => 'ઉઝ્બેક',
        'uz_AF' => 'ઉઝ્બેક (અફઘાનિસ્તાન)',
        'uz_Arab' => 'ઉઝ્બેક (અરબી)',
        'uz_Arab_AF' => 'ઉઝ્બેક (અરબી, અફઘાનિસ્તાન)',
        'uz_Cyrl' => 'ઉઝ્બેક (સિરિલિક)',
        'uz_Cyrl_UZ' => 'ઉઝ્બેક (સિરિલિક, ઉઝ્બેકિસ્તાન)',
        'uz_Latn' => 'ઉઝ્બેક (લેટિન)',
        'uz_Latn_UZ' => 'ઉઝ્બેક (લેટિન, ઉઝ્બેકિસ્તાન)',
        'uz_UZ' => 'ઉઝ્બેક (ઉઝ્બેકિસ્તાન)',
        'vi' => 'વિયેતનામીસ',
        'vi_VN' => 'વિયેતનામીસ (વિયેતનામ)',
        'wo' => 'વોલોફ',
        'wo_SN' => 'વોલોફ (સેનેગલ)',
        'xh' => 'ખોસા',
        'xh_ZA' => 'ખોસા (દક્ષિણ આફ્રિકા)',
        'yi' => 'યિદ્દિશ',
        'yi_001' => 'યિદ્દિશ (વિશ્વ)',
        'yo' => 'યોરૂબા',
        'yo_BJ' => 'યોરૂબા (બેનિન)',
        'yo_NG' => 'યોરૂબા (નાઇજેરિયા)',
        'zh' => 'ચાઇનીઝ',
        'zh_CN' => 'ચાઇનીઝ (ચીન)',
        'zh_HK' => 'ચાઇનીઝ (હોંગકોંગ SAR ચીન)',
        'zh_Hans' => 'ચાઇનીઝ (સરળીકૃત)',
        'zh_Hans_CN' => 'ચાઇનીઝ (સરળીકૃત, ચીન)',
        'zh_Hans_HK' => 'ચાઇનીઝ (સરળીકૃત, હોંગકોંગ SAR ચીન)',
        'zh_Hans_MO' => 'ચાઇનીઝ (સરળીકૃત, મકાઉ SAR ચીન)',
        'zh_Hans_SG' => 'ચાઇનીઝ (સરળીકૃત, સિંગાપુર)',
        'zh_Hant' => 'ચાઇનીઝ (પરંપરાગત)',
        'zh_Hant_HK' => 'ચાઇનીઝ (પરંપરાગત, હોંગકોંગ SAR ચીન)',
        'zh_Hant_MO' => 'ચાઇનીઝ (પરંપરાગત, મકાઉ SAR ચીન)',
        'zh_Hant_TW' => 'ચાઇનીઝ (પરંપરાગત, તાઇવાન)',
        'zh_MO' => 'ચાઇનીઝ (મકાઉ SAR ચીન)',
        'zh_SG' => 'ચાઇનીઝ (સિંગાપુર)',
        'zh_TW' => 'ચાઇનીઝ (તાઇવાન)',
        'zu' => 'ઝુલુ',
        'zu_ZA' => 'ઝુલુ (દક્ષિણ આફ્રિકા)',
    ],
];
